@@ -1,5 +1,5 @@
 # Obtain shared config values
-import os, sys
+import sys
 from os.path import abspath, join, dirname
 
 sys.path.append(abspath(join(dirname(__file__), "..")))
@@ -10,14 +10,6 @@ from shared_conf import *
 extensions.append("sphinx.ext.autodoc")
 autodoc_default_flags = ["members", "special-members"]
 
-# Enable & configure doctest
-extensions.append("sphinx.ext.doctest")
-# Import mock tooling from unit tests' _util.py
-doctest_path = [abspath(join(dirname(__file__), "..", "..", "tests"))]
-doctest_global_setup = r"""
-from _util import MockRemote, MockSFTP, Session, Command
-"""
-
 # Default is 'local' building, but reference the public WWW site when building
 # under RTD.
 target = join(dirname(__file__), "..", "www", "_build")
