@@ -20,11 +20,11 @@ from invoke.vendor.lexicon import Lexicon
 from invoke.config import Config as InvokeConfig
 from invoke.exceptions import ThreadException
 
-from fabric import Config as Config_
+from fabric import Config, Connection
 from fabric.exceptions import InvalidV1Env
 from fabric.util import get_local_user
 
-from _util import support, Connection, Config, faux_v1_env
+from _util import support, faux_v1_env
 
 
 # Remote is woven in as a config default, so must be patched there
@@ -265,7 +265,7 @@ class Connection_:
                 runtime_path = join(support, "ssh_config", confname)
                 if overrides is None:
                     overrides = {}
-                return Config_(
+                return Config(
                     runtime_ssh_path=runtime_path, overrides=overrides
                 )
 
@@ -274,7 +274,7 @@ class Connection_:
                 return Connection("runtime", config=config)
 
             def effectively_blank_when_no_loaded_config(self):
-                c = Config_(ssh_config=SSHConfig())
+                c = Config(ssh_config=SSHConfig())
                 cxn = Connection("host", config=c)
                 # NOTE: paramiko always injects this even if you look up a host
                 # that has no rules, even wildcard ones.
@@ -306,7 +306,7 @@ class Connection_:
                     path = join(
                         support, "ssh_config", "overridden_hostname.conf"
                     )
-                    config = Config_(runtime_ssh_path=path)
+                    config = Config(runtime_ssh_path=path)
                     cxn = Connection("aliasname", config=config)
                     assert cxn.host == "realname"
                     assert cxn.original_host == "aliasname"
@@ -859,7 +859,7 @@ class Connection_:
                 config_kwargs["overrides"] = {
                     "connect_kwargs": {"key_filename": ["configured.key"]}
                 }
-            conf = Config_(**config_kwargs)
+            conf = Config(**config_kwargs)
             connect_kwargs = {}
             if kwarg:
                 # Stitch in connect_kwargs value
